Lie Conformal Algebras
======================

The main classes to work with Lie conformal algebras
----------------------------------------------------

.. toctree::

    ../sage/algebras/lie_conformal_algebras/lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/examples
    ../sage/algebras/lie_conformal_algebras/lie_conformal_algebra_element

.. SEEALSO::

    :mod:`The Category of Lie Conformal Algebras<sage.categories.lie_conformal_algebras>`

Implemented examples of Lie Conformal Algebras
----------------------------------------------

.. toctree::

    ../sage/algebras/lie_conformal_algebras/abelian_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/affine_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/bosonic_ghosts_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/fermionic_ghosts_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/free_bosons_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/free_fermions_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/n2_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/neveu_schwarz_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/virasoro_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/weyl_lie_conformal_algebra


See also
--------

.. toctree::

    ../sage/algebras/lie_conformal_algebras/finitely_freely_generated_lca
    ../sage/algebras/lie_conformal_algebras/freely_generated_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/graded_lie_conformal_algebra
    ../sage/algebras/lie_conformal_algebras/lie_conformal_algebra_with_basis
    ../sage/algebras/lie_conformal_algebras/lie_conformal_algebra_with_structure_coefs
